helps = dict(
    run = '''run shell cmd on target
    ''',
    module = '''show module's help
    ''',
    modules = '''list modules
        arg = search pattern
    ''',
    deploy = '''deploy module
    ''',
    remote = '''deploy module remotly
    ''',
    update = '''update packages
    ''',
    upgrade = '''upgrade packages
        May hang, if user input is required.
    ''',
    installed = '''list installed packages
    ''',
    available = '''list avaiable packages
    ''',
    bigs = '''list the bigest installed packages
    ''',
    upgradable = '''list upgradble packages
    ''',
    install = '''install package
    ''',
    remove = '''remove package
    ''',
    cleanup = '''cleanup packages
    ''',
    status = '''query service status
    ''',
    start = '''start service
    ''',
    stop = '''stop service
    ''',
    restart = '''restart service
    ''',
    enable = '''enable service
    ''',
    disable = '''disable service
    ''',
    download = '''download file
    ''',
    logs = '''show log file
        arg = level (default to "info")
    ''',
    outrun = '''show commands history
    ''',
    outlog = '''show commands log
    ''',
)
